<?php
/**
 * Returns countries for given criteria.
 *
 * @param string $region
 * @param string $language
 *
 * @return array
 */
function langbf_get_countries( $region, $language ) {

	$supported_regions = array( 'europe', 'america', 'asia', 'africa', 'all' );
	$supported_languages = array( 'native', 'english' );

	if ( ! in_array( $region, $supported_regions ) || ! in_array( $language, $supported_languages ) ) {
		return array();
	}

	// Array of europe country codes with thier names in native language
	$europe_native = array(
		'ad' => 'Andorra',
		'at' => 'Österreich',
		'al' => 'Shqipëria',
		'ba' => 'Bosna i Hercegovina',
		'be' => 'Belgien',
		'bg' => 'България',
		'by' => 'Беларусь',
		'ch' => 'Schweiz',
		'cz' => 'Česko',
		'de' => 'Deutschland',
		'dk' => 'Danmark',
		'ee' => 'Eesti',
		'es' => 'España',
		'fi' => 'Suomi',
		'fo' => 'Føroyar',
		'fr' => 'France',
		'gg' => 'Guernesey',
		'gi' => 'Gibraltar',
		'gr' => 'Ελλάδα',
		'hr' => 'Hrvatska',
		'hu' => 'Magyarország',
		'ie' => 'Ireland/Éire',
		'im' => 'Ellan Vannin',
		'is' => 'Ísland',
		'it' => 'Italia',
		'je' => 'Jersey',
		'li' => 'Liechtenstein',
		'lt' => 'Lietuva',
		'lu' => 'Luxemburg',
		'lv' => 'Latvija',
		'mc' => 'Monaco',
		'md' => 'Moldova',
		'me' => 'Црна Гор',
		'mk' => 'Македонија',
		'mt' => 'Malta',
		'nc-tr' => 'Kuzey Kıbrıs Türk Cumhuriyeti',
		'nl' => 'Nederland',
		'no' => 'Norge',
		'pl' => 'Polska',
		'pt' => 'Portugal',
		'ro' => 'România',
		'rs' => 'Србија',
		'ru' => 'Россия',
		'se' => 'Sverige',
		'si' => 'Slovenija',
		'sk' => 'Slovensko',
		'sm' => 'San Marino',
		'tr' => 'Türkiye',
		'ua' => 'Україна',
		'uk' => 'United Kingdom',
		'va' => 'Vatican',
		'xk' => 'Kosovë',
	);
/*
		'abk' => 'Аҧсны',
		'amd' => 'Լեռնային Ղարաբաղի Հանրապետություն',
		'soos' => 'Республикæ Хуссар Ирыстон',
		'373' => 'Transnistria',
		'ax' => 'Åland',
		'rs-ba' => 'Република Српска',
		'sj' => 'Svalbard and Jan Mayen',
*/

	// Array of europe country codes with thier names in english language, just for admin panel to manage it easy
	$europe_english = array(
		'ad' => __( 'Andorra', LANGBF_TD ),
		'at' => __( 'Austria', LANGBF_TD ),
		'al' => __( 'Albania', LANGBF_TD ),
		'ba' => __( 'Bosnia and Herzegovina', LANGBF_TD ),
		'be' => __( 'Belgium', LANGBF_TD ),
		'bg' => __( 'Bulgaria', LANGBF_TD ),
		'by' => __( 'Belarus', LANGBF_TD ),
		'ch' => __( 'Switzerland', LANGBF_TD ),
		'cz' => __( 'Czech Republic', LANGBF_TD ),
		'de' => __( 'Germany', LANGBF_TD ),
		'dk' => __( 'Denmark', LANGBF_TD ),
		'ee' => __( 'Estonia', LANGBF_TD ),
		'es' => __( 'Spain', LANGBF_TD ),
		'fi' => __( 'Finland', LANGBF_TD ),
		'fo' => __( 'Faroe Islands', LANGBF_TD ),
		'fr' => __( 'France', LANGBF_TD ),
		'gg' => __( 'Guernsey', LANGBF_TD ),
		'gi' => __( 'Gibraltar', LANGBF_TD ),
		'gr' => __( 'Greece', LANGBF_TD ),
		'hr' => __( 'Croatia', LANGBF_TD ),
		'hu' => __( 'Hungary', LANGBF_TD ),
		'ie' => __( 'Ireland', LANGBF_TD ),
		'im' => __( 'Isle of Man', LANGBF_TD ),
		'is' => __( 'Iceland', LANGBF_TD ),
		'it' => __( 'Italy', LANGBF_TD ),
		'je' => __( 'Jersey', LANGBF_TD ),
		'li' => __( 'Liechtenstein', LANGBF_TD ),
		'lt' => __( 'Lithuania', LANGBF_TD ),
		'lu' => __( 'Luxembourg', LANGBF_TD ),
		'lv' => __( 'Latvia', LANGBF_TD ),
		'mc' => __( 'Monaco', LANGBF_TD ),
		'md' => __( 'Moldova', LANGBF_TD ),
		'me' => __( 'Montenegro', LANGBF_TD ),
		'mk' => __( 'Macedonia', LANGBF_TD ),
		'mt' => __( 'Malta', LANGBF_TD ),
		'nc-tr' => __( 'Northern Cyprus', LANGBF_TD ),
		'nl' => __( 'Netherlands', LANGBF_TD ),
		'no' => __( 'Norway', LANGBF_TD ),
		'pl' => __( 'Poland', LANGBF_TD ),
		'pt' => __( 'Portugal', LANGBF_TD ),
		'ro' => __( 'Romania', LANGBF_TD ),
		'rs' => __( 'Serbia', LANGBF_TD ),
		'ru' => __( 'Russian Federation', LANGBF_TD ),
		'se' => __( 'Sweden', LANGBF_TD ),
		'si' => __( 'Slovenia', LANGBF_TD ),
		'sk' => __( 'Slovakia', LANGBF_TD ),
		'sm' => __( 'San Marino', LANGBF_TD ),
		'tr' => __( 'Turkey', LANGBF_TD ),
		'ua' => __( 'Ukraine', LANGBF_TD ),
		'uk' => __( 'United Kingdom', LANGBF_TD ),
		'va' => __( 'Vatican', LANGBF_TD ),
		'xk' => __( 'Kosovo', LANGBF_TD ),
	);
/*
		'abk' => __( 'Abkhazia', LANGBF_TD ),
		'amd' => __( 'Nagorno-Karabakh', LANGBF_TD ),
		'soos' => __( 'South Ossetia', LANGBF_TD ),
		'373' => __( 'Transnistria', LANGBF_TD ),
		'ax' => __( 'Åland', LANGBF_TD ),
		'rs-ba' => __( 'Republika Srpska', LANGBF_TD ),
		'sj' => __( 'Svalbard and Jan Mayen', LANGBF_TD ),
*/

	// Array of americas country codes with thier names in native language
	$america_native = array(
		'ag' => 'Antigua and Barbuda',
		'ai' => 'Anguilla',
		'ar' => 'Argentina',
		'aw' => 'Aruba',
		'bb' => 'Barbados',
		'bo' => 'Bolivia',
		'br' => 'Brasil',
		'bm' => 'Bermuda',
		'bs' => 'Bahamas',
		'bz' => 'Belize',
		'ca' => 'Canada',
		'cl' => 'Chile',
		'co' => 'Colombia',
		'cr' => 'Costa Rica',
		'cu' => 'Cuba',
		'dm' => 'Dominique',
		'do' => 'República Dominicana',
		'ec' => 'Ecuador',
		'gd' => 'Grenada',
		'gl' => 'Kalaallit Nunaat',
		'gt' => 'Guatemala',
		'gy' => 'Guyana',
		'hn' => 'Honduras',
		'ht' => 'Haïti',
		'jm' => 'Jamaica',
		'kn' => 'Saint Kitts and Nevis',
		'ky' => 'Cayman Islands',
		'lc' => 'Saint Lucia',
		'ms' => 'Montserrat',
		'mx' => 'México',
		'ni' => 'Nicaragua',
		'pa' => 'Panamá',
		'pe' => 'Perú',
		'pr' => 'Puerto Rico',
		'py' => 'Paraguay',
		'sr' => 'Suriname',
		'sv' => 'El Salvador',
		'tc' => 'Turks and Caicos Islands',
		'tt' => 'Trinidad and Tobago',
		'us' => 'United States',
		'uy' => 'Uruguay',
		'vc' => 'Saint Vincent and the Grenadines',
		've' => 'Venezuela',
		'vg' => 'British Virgin Islands',
		'vi' => 'United States Virgin Islands',
	);
/*
		'pm' => 'Saint Pierre and Miquelon',
		'nl-bo' => 'Bonaire',
		'cw' => 'Curaçao',
		'fr-gd' => 'Guadeloupe',
		'fr-ma' => 'Martinique',
		'bq' => 'Navassa Island',
		'nl-sa' => 'Saba',
		'bl' => 'Saint Barthélemy',
		'mf' => 'Saint Martin',
		'nl-se' => 'Sint Eustatius',
		'sx' => 'Sint Maarten',
		'fk' => 'Falkland Islands',
		'fr-gu' => 'Guyane française',
		'gs' => 'South Georgia and South Sandwich Islands',
*/

	// Array of americas country codes with thier names in english language, just for admin panel to manage it easy
	$america_english = array(
		'ag' => __( 'Antigua and Barbuda', LANGBF_TD ),
		'ai' => __( 'Anguilla', LANGBF_TD ),
		'ar' => __( 'Argentina', LANGBF_TD ),
		'aw' => __( 'Aruba', LANGBF_TD ),
		'bb' => __( 'Barbados', LANGBF_TD ),
		'bm' => __( 'Bermuda', LANGBF_TD ),
		'bo' => __( 'Bolivia', LANGBF_TD ),
		'br' => __( 'Brazil', LANGBF_TD ),
		'bs' => __( 'Bahamas', LANGBF_TD ),
		'bz' => __( 'Belize', LANGBF_TD ),
		'ca' => __( 'Canada', LANGBF_TD ),
		'cl' => __( 'Chile', LANGBF_TD ),
		'co' => __( 'Colombia', LANGBF_TD ),
		'cr' => __( 'Costa Rica', LANGBF_TD ),
		'cu' => __( 'Cuba', LANGBF_TD ),
		'dm' => __( 'Dominica', LANGBF_TD ),
		'do' => __( 'Dominican Republic', LANGBF_TD ),
		'ec' => __( 'Ecuador', LANGBF_TD ),
		'gd' => __( 'Grenada', LANGBF_TD ),
		'gl' => __( 'Greenland', LANGBF_TD ),
		'gt' => __( 'Guatemala', LANGBF_TD ),
		'gy' => __( 'Guyana', LANGBF_TD ),
		'hn' => __( 'Honduras', LANGBF_TD ),
		'ht' => __( 'Haiti', LANGBF_TD ),
		'jm' => __( 'Jamaica', LANGBF_TD ),
		'kn' => __( 'Saint Kitts and Nevis', LANGBF_TD ),
		'ky' => __( 'Cayman Islands', LANGBF_TD ),
		'lc' => __( 'Saint Lucia', LANGBF_TD ),
		'ms' => __( 'Montserrat', LANGBF_TD ),
		'mx' => __( 'Mexico', LANGBF_TD ),
		'ni' => __( 'Nicaragua', LANGBF_TD ),
		'pa' => __( 'Panama', LANGBF_TD ),
		'pe' => __( 'Peru', LANGBF_TD ),
		'pr' => __( 'Puerto Rico', LANGBF_TD ),
		'py' => __( 'Paraguay', LANGBF_TD ),
		'sr' => __( 'Suriname', LANGBF_TD ),
		'sv' => __( 'El Salvador', LANGBF_TD ),
		'tc' => __( 'Turks and Caicos Islands', LANGBF_TD ),
		'tt' => __( 'Trinidad and Tobago', LANGBF_TD ),
		'us' => __( 'United States', LANGBF_TD ),
		'uy' => __( 'Uruguay', LANGBF_TD ),
		'vc' => __( 'Saint Vincent and the Grenadines', LANGBF_TD ),
		've' => __( 'Venezuela', LANGBF_TD ),
		'vg' => __( 'British Virgin Islands', LANGBF_TD ),
		'vi' => __( 'United States Virgin Islands', LANGBF_TD ),
	);
/*
		'pm' => __( 'Saint Pierre and Miquelon', LANGBF_TD ),
		'nl-bo' => __( 'Bonaire', LANGBF_TD ),
		'cw' => __( 'Curaçao', LANGBF_TD ),
		'fr-gd' => __( 'Guadeloupe', LANGBF_TD ),
		'fr-ma' => __( 'Martinique', LANGBF_TD ),
		'bq' => __( 'Navassa Island', LANGBF_TD ),
		'nl-sa' => __( 'Saba', LANGBF_TD ),
		'bl' => __( 'Saint Barthélemy', LANGBF_TD ),
		'mf' => __( 'Saint Martin', LANGBF_TD ),
		'nl-se' => __( 'Sint Eustatius', LANGBF_TD ),
		'sx' => __( 'Sint Maarten', LANGBF_TD ),
		'fk' => __( 'Falkland Islands', LANGBF_TD ),
		'fr-gu' => __( 'French Guiana', LANGBF_TD ),
		'gs' => __( 'South Georgia and South Sandwich Islands', LANGBF_TD ),
*/

	// Array of asia country codes with thier names in native language
	$asia_native = array(
		'ae' => 'دولة الإمارات العربية المتحدة',
		'af' => 'افغانستان',
		'am' => 'Հայաստան',
		'as' => 'Amerika Sāmoa',
		'au' => 'Australia',
		'az' => 'Azərbaycan',
		'bd' => 'বাংলাদেশ',
		'bh' => '‏البحرين',
		'bn' => 'نڬارا بروني دارالسلام',
		'bt' => 'འབྲུག་ཡུལ་',
		'ck' => 'Kūki \'Āirani',
		'cl' => 'Rapa Nui',
		'cn' => '中国/中华',
		'cy' => 'Κύπρος',
		'fj' => 'Viti',
		'fm' => 'Federated States of Micronesia',
		'ge' => 'საქართველო',
		'gu' => 'Guåhån',
		'hk' => '香港',
		'id' => 'Indonesia',
		'in' => 'भारत गणराज्य',
		'il' => 'מְדִינַת יִשְׂרָאֵל',
		'iq' => 'العراق',
		'ir' => 'ایران',
		'jo' => 'اَلأُرْدُن',
		'jp' => '日本',
		'kg' => 'Кыргызстан',
		'kh' => 'Kâmpŭchéa',
		'ki' => 'Kiribati',
		'kp' => '朝鮮民主主義人民共和國',
		'kr' => '大韓民國',
		'kw' => 'دولة الكويت',
		'kz' => 'Қазақстан',
		'la' => 'ສາທາລະນະລັດ ປະຊາທິປະໄຕ ປະຊາຊົນລາວ',
		'lb' => 'لُبْنَان',
		'lk' => 'ශ්‍රී ලංකා',
		'mh' => 'Marshall Islands',
		'mn' => 'Монгол улс',
		'mm' => 'Myanmar',
		'mo' => '澳門',
		'mv' => 'ދިވެހިރާއްޖެ',
		'my' => 'Malaysia',
		'nc' => 'Nouvelle-Calédonie',
		'np' => 'नेपाल',
		'nr' => 'Nauru',
		'nz' => 'New Zealand',
		'om' => 'عمان',
		'pf' => 'Polynésie française',
		'pg' => 'Papua Niugini',
		'ph' => 'Pilipinas',
		'pk' => 'پاکِستان',
		'ps' => 'فلسطين',
		'pw' => 'Palau',
		'qa' => 'قطر',
		'sa' => 'العربية السعودية',
		'sb' => 'Solomon Islands',
		'sg' => 'Singapore',
		'sy' => 'سورية',
		'th' => 'ประเทศไทย',
		'tj' => 'Тоҷикистон',
		'tl' => 'Timór Lorosa\'e',
		'tm' => 'Türkmenistan',
		'to' => 'Tonga',
		'tv' => 'Tuvalu',
		'tw' => '台灣',
		'uz' => 'O‘zbekiston',
		'vn' => 'Việt Nam',
		'vu' => 'Vanuatu',
		'ws' => 'Sāmoa',
		'ye' => 'الجمهورية اليمنية',
	);
/*
		'cy-ad' => 'Akrotiri and Dhekelia',
		'io' => 'British Indian Ocean Territory',
		'cx' => 'Christmas Island',
		'cc' => 'Cocos (Keeling) Islands',
		'nf' => 'Norfolk Island',
		'mp' => 'Northern Mariana Islands',
		'um' => 'Wake Island',
		'us-ha' => 'Hawaiʻi',
		'nu' => 'Niuē',
		'pn' => 'Pitcairn Islands',
		'tk' => 'Tokelau',
		'wf' => 'Wallis et Futuna',
*/

	// Array of asia country codes with thier names in english language, just for admin panel to manage it easy
	$asia_english = array(
		'ae' => __( 'United Arab Emirates', LANGBF_TD ),
		'af' => __( 'Afghanistan', LANGBF_TD ),
		'am' => __( 'Armenia', LANGBF_TD ),
		'as' => __( 'American Samoa', LANGBF_TD ),
		'au' => __( 'Australia', LANGBF_TD ),
		'az' => __( 'Azerbaijan', LANGBF_TD ),
		'bd' => __( 'Bangladesh', LANGBF_TD ),
		'bh' => __( 'Bahrain', LANGBF_TD ),
		'bn' => __( 'Brunei', LANGBF_TD ),
		'bt' => __( 'Bhutan', LANGBF_TD ),
		'ck' => __( 'Cook Islands', LANGBF_TD ),
		'cl' => __( 'Easter Island', LANGBF_TD ),
		'cn' => __( 'China', LANGBF_TD ),
		'cy' => __( 'Cyprus', LANGBF_TD ),
		'fj' => __( 'Fiji', LANGBF_TD ),
		'fm' => __( 'Federated States of Micronesia', LANGBF_TD ),
		'ge' => __( 'Georgia', LANGBF_TD ),
		'gu' => __( 'Guam', LANGBF_TD ),
		'hk' => __( 'Hong Kong', LANGBF_TD ),
		'id' => __( 'Indonesia', LANGBF_TD ),
		'il' => __( 'Israel', LANGBF_TD ),
		'in' => __( 'India', LANGBF_TD ),
		'iq' => __( 'Iraq', LANGBF_TD ),
		'ir' => __( 'Iran', LANGBF_TD ),
		'jo' => __( 'Jordan', LANGBF_TD ),
		'jp' => __( 'Japan', LANGBF_TD ),
		'kg' => __( 'Kyrgyzstan', LANGBF_TD ),
		'kh' => __( 'Cambodia', LANGBF_TD ),
		'ki' => __( 'Kiribati', LANGBF_TD ),
		'kp' => __( 'North Korea', LANGBF_TD ),
		'kr' => __( 'South Korea', LANGBF_TD ),
		'kw' => __( 'Kuwait', LANGBF_TD ),
		'kz' => __( 'Kazakhstan', LANGBF_TD ),
		'la' => __( 'Laos', LANGBF_TD ),
		'lb' => __( 'Lebanon', LANGBF_TD ),
		'lk' => __( 'Sri Lanka', LANGBF_TD ),
		'mh' => __( 'Marshall Islands', LANGBF_TD ),
		'mn' => __( 'Mongolia', LANGBF_TD ),
		'mm' => __( 'Myanmar', LANGBF_TD ),
		'mo' => __( 'Macau', LANGBF_TD ),
		'mv' => __( 'Maldives', LANGBF_TD ),
		'my' => __( 'Malaysia', LANGBF_TD ),
		'nc' => __( 'New Caledonia', LANGBF_TD ),
		'np' => __( 'Nepal', LANGBF_TD ),
		'nr' => __( 'Nauru', LANGBF_TD ),
		'nz' => __( 'New Zealand', LANGBF_TD ),
		'om' => __( 'Oman', LANGBF_TD ),
		'pf' => __( 'French Polynesia', LANGBF_TD ),
		'pg' => __( 'Papua New Guinea', LANGBF_TD ),
		'ph' => __( 'Philippines', LANGBF_TD ),
		'pk' => __( 'Pakistan', LANGBF_TD ),
		'ps' => __( 'Palestine', LANGBF_TD ),
		'pw' => __( 'Palau', LANGBF_TD ),
		'qa' => __( 'Qatar', LANGBF_TD ),
		'sa' => __( 'Saudi Arabia', LANGBF_TD ),
		'sb' => __( 'Solomon Islands', LANGBF_TD ),
		'sg' => __( 'Singapore', LANGBF_TD ),
		'sy' => __( 'Syria', LANGBF_TD ),
		'tj' => __( 'Tajikistan', LANGBF_TD ),
		'th' => __( 'Thailand', LANGBF_TD ),
		'tl' => __( 'Timor-Leste', LANGBF_TD ),
		'tm' => __( 'Turkmenistan', LANGBF_TD ),
		'to' => __( 'Tonga', LANGBF_TD ),
		'tv' => __( 'Tuvalu', LANGBF_TD ),
		'tw' => __( 'Taiwan', LANGBF_TD ),
		'uz' => __( 'Uzbekistan', LANGBF_TD ),
		'vn' => __( 'Vietnam', LANGBF_TD ),
		'vu' => __( 'Vanuatu', LANGBF_TD ),
		'ws' => __( 'Samoa', LANGBF_TD ),
		'ye' => __( 'Yemen', LANGBF_TD ),
	);
/*
		'cy-ad' => __( 'Akrotiri and Dhekelia', LANGBF_TD ),
		'io' => __( 'British Indian Ocean Territory', LANGBF_TD ),
		'cx' => __( 'Christmas Island', LANGBF_TD ),
		'cc' => __( 'Cocos (Keeling) Islands', LANGBF_TD ),
		'nf' => __( 'Norfolk Island', LANGBF_TD ),
		'mp' => __( 'Northern Mariana Islands', LANGBF_TD ),
		'um' => __( 'Wake Island', LANGBF_TD ),
		'us-ha' => __( 'Hawaii', LANGBF_TD ),
		'nu' => __( 'Niue', LANGBF_TD ),
		'pn' => __( 'Pitcairn Islands', LANGBF_TD ),
		'tk' => __( 'Tokelau', LANGBF_TD ),
		'wf' => __( 'Wallis and Futuna', LANGBF_TD ),
*/

	// Array of africa country codes with thier names in native language
	$africa_native = array(
		'ao' => 'Angola',
		'bf' => 'Burkina Faso',
		'bi' => 'Burundi',
		'bj' => 'Bénin',
		'bw' => 'Botswana',
		'cd' => 'République démocratique du Congo',
		'cf' => 'Centrafrique',
		'cg' => 'République du Congo',
		'ci' => 'Côte d\'Ivoire',
		'cm' => 'Cameroun',
		'cv' => 'Cabo Verde',
		'dj' => 'Djibouti',
		'dz' => 'الجزائر‎',
		'eg' => 'مصر',
		'eh' => 'الجمهورية العربية الصحراوية الديمقراطية',
		'er' => 'ኤርትራ',
		'et' => 'ኢትዮጵያ',
		'ga' => 'Gabon',
		'gh' => 'Ghana',
		'gm' => 'Gambia',
		'gn' => 'Guinea',
		'gq' => 'Guinea Ecuatorial',
		'gw' => 'Guiné-Bissau',
		'ke' => 'Kenya',
		'km' => 'Union des Comores',
		'lr' => 'Liberia',
		'ls' => 'Lesotho',
		'ly' => 'ليبيا‎',
		'ma' => 'المغرب‎',
		'mg' => 'Madagasikara',
		'ml' => 'Mali',
		'mr' => 'موريتانيا',
		'mu' => 'Moris',
		'mw' => 'Malawi',
		'mz' => 'Moçambique',
		'na' => 'Namibia',
		'ne' => 'Niger',
		'ng' => 'Nigeria',
		're' => 'Réunion',
		'rw' => 'Rwanda',
		'sc' => 'Seychelles',
		'sd' => 'السودان‎',
		'sl' => 'Sierra Leone',
		'sn' => 'le Sénégal',
		'so' => 'Soomaaliya',
		'st' => 'São Tomé and Príncipe',
		'sz' => 'Swaziland',
		'td' => 'Tchad',
		'tg' => 'Togo',
		'tn' => 'تونس‎',
		'tz' => 'Tanzania',
		'ug' => 'Uganda',
		'za' => 'South Africa',
		'zm' => 'Zambia',
		'zw' => 'Zimbabwe',
	);
/*
		'ic' => 'Islas Canarias',
		'es-ce' => 'Ceuta',
		'pt-30' => 'Madeira',
		'yt' => 'Mayotte',
		'es-ml' => 'Melilla',
		'sh' => 'Saint Helena',
		'ss' => 'South Sudan',
*/

	// Array of africa country codes with thier names in english language, just for admin panel to manage it easy
	$africa_english = array(
		'ao' => __( 'Angola', LANGBF_TD ),
		'bf' => __( 'Burkina Faso', LANGBF_TD ),
		'bi' => __( 'Burundi', LANGBF_TD ),
		'bj' => __( 'Benin', LANGBF_TD ),
		'bw' => __( 'Botswana', LANGBF_TD ),
		'cd' => __( 'Democratic Republic of the Congo', LANGBF_TD ),
		'cf' => __( 'Central African Republic', LANGBF_TD ),
		'cg' => __( 'Republic of the Congo', LANGBF_TD ),
		'ci' => __( 'Côte d\'Ivoire', LANGBF_TD ),
		'cm' => __( 'Cameroon', LANGBF_TD ),
		'cv' => __( 'Cape Verde', LANGBF_TD ),
		'dj' => __( 'Djibouti', LANGBF_TD ),
		'dz' => __( 'Algeria', LANGBF_TD ),
		'eg' => __( 'Egypt', LANGBF_TD ),
		'eh' => __( 'Sahrawi Arab Democratic Republic', LANGBF_TD ),
		'er' => __( 'Eritrea', LANGBF_TD ),
		'et' => __( 'Ethiopia', LANGBF_TD ),
		'ga' => __( 'Gabon', LANGBF_TD ),
		'gh' => __( 'Ghana', LANGBF_TD ),
		'gm' => __( 'Gambia', LANGBF_TD ),
		'gn' => __( 'Guinea', LANGBF_TD ),
		'gq' => __( 'Equatorial Guinea', LANGBF_TD ),
		'gw' => __( 'Guinea-Bissau', LANGBF_TD ),
		'ke' => __( 'Kenya', LANGBF_TD ),
		'km' => __( 'Comoros', LANGBF_TD ),
		'lr' => __( 'Liberia', LANGBF_TD ),
		'ls' => __( 'Lesotho', LANGBF_TD ),
		'ly' => __( 'Libya', LANGBF_TD ),
		'ma' => __( 'Morocco', LANGBF_TD ),
		'mg' => __( 'Madagascar', LANGBF_TD ),
		'ml' => __( 'Mali', LANGBF_TD ),
		'mr' => __( 'Mauritania', LANGBF_TD ),
		'mu' => __( 'Mauritius', LANGBF_TD ),
		'mw' => __( 'Malawi', LANGBF_TD ),
		'mz' => __( 'Mozambique', LANGBF_TD ),
		'na' => __( 'Namibia', LANGBF_TD ),
		'ne' => __( 'Niger', LANGBF_TD ),
		'ng' => __( 'Nigeria', LANGBF_TD ),
		're' => __( 'Réunion', LANGBF_TD ),
		'rw' => __( 'Rwanda', LANGBF_TD ),
		'sc' => __( 'Seychelles', LANGBF_TD ),
		'sd' => __( 'Sudan', LANGBF_TD ),
		'sl' => __( 'Sierra Leone', LANGBF_TD ),
		'sn' => __( 'Senegal', LANGBF_TD ),
		'so' => __( 'Somalia', LANGBF_TD ),
		'st' => __( 'São Tomé and Príncipe', LANGBF_TD ),
		'sz' => __( 'Swaziland', LANGBF_TD ),
		'td' => __( 'Chad', LANGBF_TD ),
		'tg' => __( 'Togo', LANGBF_TD ),
		'tn' => __( 'Tunisia', LANGBF_TD ),
		'tz' => __( 'Tanzania', LANGBF_TD ),
		'ug' => __( 'Uganda', LANGBF_TD ),
		'za' => __( 'South Africa', LANGBF_TD ),
		'zm' => __( 'Zambia', LANGBF_TD ),
		'zw' => __( 'Zimbabwe', LANGBF_TD ),
	);
/*
		'ic' => __( 'Canary Islands', LANGBF_TD ),
		'es-ce' => __( 'Ceuta', LANGBF_TD ),
		'pt-30' => __( 'Madeira', LANGBF_TD ),
		'yt' => __( 'Mayotte', LANGBF_TD ),
		'es-ml' => __( 'Melilla', LANGBF_TD ),
		'sh' => __( 'Saint Helena', LANGBF_TD ),
		'ss' => __( 'South Sudan', LANGBF_TD ),
*/


	if ( $region == 'all' ) {
		$countries = array_merge( ${'europe_' . $language}, ${'america_' . $language}, ${'asia_' . $language}, ${'africa_' . $language} );
	} else {
		$countries = ${$region . '_' . $language};
	}

	return apply_filters( 'langbf_countries', $countries, $region, $language );
}

